@@ -34,6 +34,7 @@
 #include <map>
 
 using namespace std;
+using namespace stringf;
 
 
 BuffyWindow::BuffyWindow()
@@ -44,11 +45,13 @@ BuffyWindow::BuffyWindow()
 
 	set_title("Buffy Folder List");
 	//set_border_width(5);
-	set_default_size(500, 300);
+	string saved_w = conf.get_application_data("buffy", "winw", "500");
+	string saved_h = conf.get_application_data("buffy", "winh", "300");
+	
+	set_default_size(atoi(saved_w.c_str()), atoi(saved_h.c_str()));
 
 	add(mainVBox);
 
-
 	// Create the actions used by Buffy
 
 	actionGroup = Gtk::ActionGroup::create("Actions");
@@ -188,6 +191,11 @@ BuffyWindow::BuffyWindow()
 	//menuBar.items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::Stock::HELP, helpMenu));
 	*/
 
+	/*
+	signal_configure_event().connect(
+			sigc::mem_fun(*this, &BuffyWindow::on_window_configure));
+	*/
+
 	show_all_children();
 }
 
@@ -203,6 +211,31 @@ void BuffyWindow::on_program_exited(int pid, int status)
 	folderList.do_update();
 }
 
+bool BuffyWindow::on_configure_event(GdkEventConfigure* c)
+{
+	bool res = Gtk::Window::on_configure_event(c);
+
+	Config& conf = Environment::get().config();
+
+	conf.set_application_data("buffy", "winx", fmt(c->x));
+	conf.set_application_data("buffy", "winy", fmt(c->y));
+	conf.set_application_data("buffy", "winw", fmt(c->width));
+	conf.set_application_data("buffy", "winh", fmt(c->height));
+
+	return res;
+}
+
+void BuffyWindow::on_show()
+{
+	Gtk::Window::on_show();
+
+	Config& conf = Environment::get().config();
+	string saved_x = conf.get_application_data("buffy", "winx");
+	string saved_y = conf.get_application_data("buffy", "winy");
+	if (saved_x != "" && saved_y != "")
+		move(atoi(saved_x.c_str()), atoi(saved_y.c_str()));
+}
+
 
 /*
 void BuffyWindow::consume(const MailFolder& folder)
